"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.EnableIndexingTaskRunner = void 0;
class EnableIndexingTaskRunner {
  constructor(manager, indexManager) {
    this.manager = manager;
    this.response = manager.response;
    this.indexManager = indexManager;
  }
  async exec(matching) {
    if (this.manager.isAborted()) {
      return this.response.aborted();
    }
    const isIndexAllowed = index => {
      if (typeof matching !== "string" || !matching) {
        return true;
      }
      return index.includes(matching);
    };
    const indexes = await this.indexManager.list();
    const enabled = [];
    const failed = [];
    for (const index of indexes) {
      if (!isIndexAllowed(index)) {
        continue;
      }
      try {
        await this.indexManager.enableIndexing(index);
        enabled.push(index);
      } catch (ex) {
        failed.push(index);
        await this.manager.store.addErrorLog({
          message: `Failed to enable indexing on index "${index}".`,
          error: ex
        });
      }
    }
    return this.response.done("Task done.", {
      enabled,
      failed
    });
  }
}
exports.EnableIndexingTaskRunner = EnableIndexingTaskRunner;

//# sourceMappingURL=EnableIndexingTaskRunner.js.map